(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    147456,       3684]
NotebookOptionsPosition[    143256,       3556]
NotebookOutlinePosition[    144888,       3606]
CellTagsIndexPosition[    144552,       3594]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Lorentz Transformation", "DemoTitle",
 CellChangeTimes->{{3.5779819508640738`*^9, 3.577981961701157*^9}}],

Cell[CellGroupData[{

Cell["", "InitializationSection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", "[", "v_", "]"}], ":=", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["v", "2"], "1"]}]]]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Lorentz", " ", "factor"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"loL", "[", 
     RowBox[{"xa_", ",", "xb_", ",", "v_"}], "]"}], ":=", 
    RowBox[{
     FractionBox["xa", "v"], "-", 
     FractionBox["xb", 
      RowBox[{
       RowBox[{"\[Gamma]", "[", "v", "]"}], " ", "v"}]]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Line", " ", "of", " ", "same", " ", "Location"}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"loS", "[", 
     RowBox[{"xa_", ",", "tb_", ",", "v_"}], "]"}], ":=", 
    RowBox[{
     FractionBox["tb", 
      RowBox[{"\[Gamma]", "[", "v", "]"}]], "+", 
     RowBox[{
      FractionBox["v", 
       SuperscriptBox["1", "2"]], "xa"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Line", " ", "of", " ", "Simultaneity"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "transform", " ", "from", " ", "B", " ", "to", " ", "A", " ", "system"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xaT", "[", 
    RowBox[{"xb_", ",", "tb_", ",", "v_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Gamma]", "[", "v", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"xb", "+", 
      RowBox[{"v", " ", "tb"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"taT", "[", 
     RowBox[{"xb_", ",", "tb_", ",", "v_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Gamma]", "[", "v", "]"}], 
     RowBox[{"(", 
      RowBox[{"tb", "+", 
       RowBox[{"v", " ", "xb"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "transform", " ", "from", " ", "A", " ", "to", " ", "B", " ", "system"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xbT", "[", 
    RowBox[{"xa_", ",", "ta_", ",", "v_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Gamma]", "[", "v", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"xa", "-", 
      RowBox[{"v", " ", "ta"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tbT", "[", 
    RowBox[{"xa_", ",", "ta_", ",", "v_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Gamma]", "[", "v", "]"}], 
    RowBox[{"(", 
     RowBox[{"ta", "-", 
      RowBox[{"v", " ", "xa"}]}], ")"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellID->43547898]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateSection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"loL", "[", 
          RowBox[{"xa", ",", "0", ",", "v"}], "]"}], ",", 
         RowBox[{"loS", "[", 
          RowBox[{"xa", ",", "0", ",", "v"}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"loL", "[", 
            RowBox[{"xa", ",", "xb", ",", "v"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"xb", ",", 
             RowBox[{"-", "20"}], ",", "20", ",", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"loS", "[", 
            RowBox[{"xa", ",", "xb", ",", "v"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"xb", ",", 
             RowBox[{"-", "20"}], ",", "20", ",", "1"}], "}"}]}], "]"}]}], 
        "}"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xa", ",", "0", ",", "7"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"n", "\[LessEqual]", "2"}], ",", "Thick", ",", 
            RowBox[{"Thickness", "[", "0.0001", "]"}]}], "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"n", "\[LessEqual]", "2"}], ",", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", "Dotted"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "84"}], "}"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", "7", "]"}], ",", 
        RowBox[{"Range", "[", "7", "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLinesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "Thin", ",", "Dotted"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "Thick"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", "\"\<\!\(\*SubscriptBox[\(x\), \(A\)]\)\>\"", "}"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", "7", "]"}], ",", 
        RowBox[{"Range", "[", "7", "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "16"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"skewed", " ", "coordinate", " ", "system"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"n", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}],
                "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"0", ",", "n", ",", "v"}], "]"}], "+", "0.2"}], ",", 
                RowBox[{"taT", "[", 
                 RowBox[{"0", ",", "n", ",", "v"}], "]"}]}], "}"}]}], "]"}], 
            ",", 
            RowBox[{"Darker", "[", "Green", "]"}], ",", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{
                   RowBox[{"-", "0.08"}], ",", "n", ",", "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{
                   RowBox[{"-", "0.08"}], ",", "n", ",", "v"}], "]"}]}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{
                   RowBox[{"+", "0.08"}], ",", "n", ",", "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{
                   RowBox[{"+", "0.08"}], ",", "n", ",", "v"}], "]"}]}], 
                "}"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"n", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}],
                "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"xaT", "[", 
                 RowBox[{"n", ",", "0", ",", "v"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"taT", "[", 
                  RowBox[{"n", ",", "0", ",", "v"}], "]"}], "+", "0.2"}]}], 
               "}"}]}], "]"}], ",", 
            RowBox[{"Darker", "[", "Green", "]"}], ",", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"n", ",", 
                   RowBox[{"-", "0.08"}], ",", "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"n", ",", 
                   RowBox[{"-", "0.08"}], ",", "v"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"n", ",", 
                   RowBox[{"+", "0.08"}], ",", "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"n", ",", 
                   RowBox[{"+", "0.08"}], ",", "v"}], "]"}]}], "}"}]}], "}"}],
              "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"sol", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Darker", "[", "Red", "]"}], ",", " ", 
            RowBox[{"Line", " ", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"7", ",", "7"}], "}"}]}], "}"}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<c\>\"", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Darker", "[", "Red", "]"}], ",", "Bold", ",", 
                  "18"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"6.85", ",", "6.65"}], "}"}]}], "]"}]}], "}"}]}], 
         "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"leader", " ", "lines"}], " ", "*)"}], "\[IndentingNewLine]",
         "Blue", ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"pta", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"pta", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"pta", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"pta", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Darker", "[", "Green", "]"}], ",", "Dashed", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"pta", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xaT", "[", 
              RowBox[{
               RowBox[{"xbT", "[", 
                RowBox[{
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", "0",
                ",", "v"}], "]"}], ",", 
             RowBox[{"taT", "[", 
              RowBox[{
               RowBox[{"xbT", "[", 
                RowBox[{
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", "0",
                ",", "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"xaT", "[", 
            RowBox[{
             RowBox[{"xbT", "[", 
              RowBox[{
               RowBox[{"pta", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"pta", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", "0", 
             ",", "v"}], "]"}], ",", 
           RowBox[{"taT", "[", 
            RowBox[{
             RowBox[{"xbT", "[", 
              RowBox[{
               RowBox[{"pta", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"pta", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", "0", 
             ",", "v"}], "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"pta", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xaT", "[", 
              RowBox[{"0", ",", 
               RowBox[{"tbT", "[", 
                RowBox[{
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
               "v"}], "]"}], ",", 
             RowBox[{"taT", "[", 
              RowBox[{"0", ",", 
               RowBox[{"tbT", "[", 
                RowBox[{
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
               "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"xaT", "[", 
            RowBox[{"0", ",", 
             RowBox[{"tbT", "[", 
              RowBox[{
               RowBox[{"pta", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"pta", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", "v"}],
             "]"}], ",", 
           RowBox[{"taT", "[", 
            RowBox[{"0", ",", 
             RowBox[{"tbT", "[", 
              RowBox[{
               RowBox[{"pta", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"pta", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", "v"}],
             "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"pta", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"pta", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"length", " ", "contraction"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "2"}], ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Darker", "[", "Green", "]"}], ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{
                   RowBox[{"xbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "0", ",", "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{
                   RowBox[{"xbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "0", ",", "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", "Blue", ",", " ", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0.03"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{
                   RowBox[{"xbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "0", ",", "v"}], "]"}], ",", "0.03"}], "}"}]}], "}"}], 
             "]"}]}], "\[IndentingNewLine]", "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"time", " ", "dilation"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "3"}], ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Darker", "[", "Green", "]"}], ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", "Blue", ",", " ", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0.03", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0.03", ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
           "\[IndentingNewLine]", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"relativity", " ", "of", " ", "simultaneity"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "4"}], ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Darker", "[", "Green", "]"}], ",", 
            RowBox[{"Thickness", "[", "0.006", "]"}], ",", "Dashed", ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{"pta", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", 
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Thickness", "[", "0.01", "]"}], ",", " ", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xaT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}], ",", 
                 RowBox[{"taT", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                   "v"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", "Blue", ",", " ", 
            RowBox[{"Thickness", "[", "0.01", "]"}], ",", " ", 
            RowBox[{"Dashing", "[", 
             RowBox[{"{", "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{"pta", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", 
                 RowBox[{"pta", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
           "\[IndentingNewLine]", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"text", " ", "frame"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Opacity", "[", "1", "]"}], ",", "White", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.5"}], ",", "7.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.5", ",", "10.2"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Lorentz Transformation\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"Black", ",", "24"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.5", ",", "9.8"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"static", " ", "FoR", " ", "frame"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Blue"}], "]"}], "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "7.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.4", ",", "9.5"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Opacity", "[", "0.2", "]"}], ",", "Blue", ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "9.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.4", ",", "9.5"}], "}"}]}], "]"}], ",", 
        RowBox[{"Opacity", "[", "1", "]"}], ",", "White", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Static FoR\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "Bold", ",", "18"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.7", ",", "9.3"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(x\), \(A\)]\) = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"pta", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
             "\"\< light seconds\>\""}], ",", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "16"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.7", ",", "8.8"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(A\)]\) = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"pta", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
             "\"\< seconds\>\""}], ",", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "16"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.5", ",", "8.5"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"length", " ", "contraction"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "2"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"\"\<\!\(\*SubscriptBox[\(l\), \(A\)]\) = \>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"xaT", "[", 
                   RowBox[{
                    RowBox[{"xbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                    "0", ",", "v"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
               "\"\< light seconds\>\""}], ",", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", "16"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.74", ",", "8.1"}], "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"time", " ", "dilation"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "3"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = \>\"", 
               "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"taT", "[", 
                   RowBox[{"0", ",", 
                    RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                    "v"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
               "\"\< seconds\>\""}], ",", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", "16"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.5", ",", "8.1"}], "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"relativity", " ", "of", " ", "simultaneity"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "4"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = \>\"", 
               "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"NumberForm", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
               "\"\< seconds\>\""}], ",", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", "16"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.5", ",", "8.1"}], "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"moving", " ", "FoR", " ", "frame"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"EdgeForm", "[", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "]"}], "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3.5", ",", "7.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.9", ",", "9.5"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
        RowBox[{"Darker", "[", "Green", "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3.5", ",", "9.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.9", ",", "9.5"}], "}"}]}], "]"}], ",", 
        RowBox[{"Opacity", "[", "1", "]"}], ",", "White", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<Moving FoR v = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{"v", ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
             "\"\< c\>\""}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Darker", "[", "Green", "]"}], ",", "Bold", ",", "18"}],
              "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.2", ",", "9.3"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(x\), \(B\)]\) = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"xbT", "[", 
                 RowBox[{
                  RowBox[{"pta", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], ",", 
                  RowBox[{"pta", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
             "\"\< light seconds\>\""}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.2", ",", "8.8"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(B\)]\) = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"tbT", "[", 
                 RowBox[{
                  RowBox[{"pta", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], ",", 
                  RowBox[{"pta", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
             "\"\< seconds\>\""}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"5", ",", "8.5"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"length", " ", "contraction"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "2"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"\"\<\!\(\*SubscriptBox[\(l\), \(B\)]\) = \>\"", "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"xbT", "[", 
                   RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
               "\"\< light seconds\>\""}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.24", ",", "8.1"}], "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"time", " ", "dilation"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "3"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = \>\"", 
               "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"tbT", "[", 
                   RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
               "\"\< seconds\>\""}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0", ",", "8.1"}], "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"relativity", " ", "of", " ", "simultaneity"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"shw", "\[Equal]", "4"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = \>\"", 
               "<>", 
               RowBox[{"ToString", "[", 
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"tbT", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}], "-", 
                   RowBox[{"tbT", "[", 
                    RowBox[{
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pta", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "v"}], "]"}]}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"{", 
                   RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}], "<>", 
               "\"\< seconds\>\""}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0", ",", "8.1"}], "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"axes", " ", "labels"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(A\)]\)\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "16"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.2", ",", "7.5"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(B\)]\)\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"xaT", "[", 
              RowBox[{"0", ",", 
               RowBox[{"7", "/", 
                RowBox[{"\[Gamma]", "[", "v", "]"}]}], ",", "v"}], "]"}], "+",
              "0.5"}], ",", "7.0"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(x\), \(B\)]\)\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Darker", "[", "Green", "]"}], ",", "16"}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.8", ",", 
            RowBox[{
             RowBox[{"loS", "[", 
              RowBox[{"7", ",", "0", ",", "v"}], "]"}], "+", "0.5"}]}], 
           "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"11", "/", "7"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "10"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"v", ",", "0.5", ",", "\"\<velocity\>\""}], "}"}], ",", "0.01", 
     ",", "0.85"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pta", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "7"}], "}"}], ",", "Locator"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"shw", ",", "1", ",", "\"\<Show:\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "\"\<coordinates only\>\""}], ",", 
       RowBox[{"2", "\[Rule]", "\"\<length contraction\>\""}], ",", 
       RowBox[{"3", "\[Rule]", "\"\<time dilation\>\""}], ",", 
       RowBox[{"4", "\[Rule]", "\"\<relativity of simultaneity\>\""}]}], 
      "}"}], ",", "PopupMenu"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sol", ",", "False", ",", "\"\<speed of light worldline\>\""}], 
      "}"}], ",", "Checkbox"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{
  3.577982003961383*^9, 3.5779833547324467`*^9, {3.5887836868437147`*^9, 
   3.5887836982448545`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`pta$$ = {3, 3}, $CellContext`shw$$ = 
    1, $CellContext`sol$$ = False, $CellContext`v$$ = 0.5, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`v$$], 0.5, "velocity"}, 0.01, 0.85}, {{
       Hold[$CellContext`pta$$], {3, 3}}, {0, 0}, {7, 7}}, {{
       Hold[$CellContext`shw$$], 1, "Show:"}, {
      1 -> "coordinates only", 2 -> "length contraction", 3 -> 
       "time dilation", 4 -> "relativity of simultaneity"}}, {{
       Hold[$CellContext`sol$$], False, "speed of light worldline"}, {
      True, False}}}, Typeset`size$$ = {500., {373., 377.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`v$5096$$ = 0, $CellContext`pta$5097$$ = {0, 
    0}, $CellContext`shw$5098$$ = False, $CellContext`sol$5099$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`pta$$ = {3, 3}, $CellContext`shw$$ = 
        1, $CellContext`sol$$ = False, $CellContext`v$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`v$$, $CellContext`v$5096$$, 0], 
        Hold[$CellContext`pta$$, $CellContext`pta$5097$$, {0, 0}], 
        Hold[$CellContext`shw$$, $CellContext`shw$5098$$, False], 
        Hold[$CellContext`sol$$, $CellContext`sol$5099$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Evaluate[
         Flatten[{
           $CellContext`loL[$CellContext`xa, 0, $CellContext`v$$], 
           $CellContext`loS[$CellContext`xa, 0, $CellContext`v$$], 
           Table[
            $CellContext`loL[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}], 
           Table[
            $CellContext`loS[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}]}]], {$CellContext`xa, 0, 7},
         PlotStyle -> Table[
          Directive[
           Darker[Green], 
           If[$CellContext`n <= 2, Thick, 
            Thickness[0.0001]], 
           If[$CellContext`n <= 2, 
            Dashing[{}], Dotted]], {$CellContext`n, 84}], GridLines -> {
          Range[7], 
          Range[7]}, GridLinesStyle -> Directive[Blue, Thin, Dotted], 
        AxesStyle -> Directive[Blue, Thick], 
        AxesLabel -> {"\!\(\*SubscriptBox[\(x\), \(A\)]\)"}, Ticks -> {
          Range[7], 
          Range[7]}, LabelStyle -> 16, Epilog -> {
          Table[{
            Text[
             Style[$CellContext`n, {
               Darker[Green], 16}], {$CellContext`xaT[
               0, $CellContext`n, $CellContext`v$$] + 0.2, 
              $CellContext`taT[0, $CellContext`n, $CellContext`v$$]}], 
            Darker[Green], 
            Dashing[{}], 
            Line[{{
               $CellContext`xaT[-0.08, $CellContext`n, $CellContext`v$$], 
               $CellContext`taT[-0.08, $CellContext`n, $CellContext`v$$]}, {
               $CellContext`xaT[
                Plus[0.08], $CellContext`n, $CellContext`v$$], 
               $CellContext`taT[
                Plus[
                0.08], $CellContext`n, $CellContext`v$$]}}]}, {$CellContext`n,
             1, 7}], 
          Table[{
            Text[
             Style[$CellContext`n, {
               Darker[Green], 16}], {
              $CellContext`xaT[$CellContext`n, 
               0, $CellContext`v$$], $CellContext`taT[$CellContext`n, 
                0, $CellContext`v$$] + 0.2}], 
            Darker[Green], 
            Dashing[{}], 
            Line[{{
               $CellContext`xaT[$CellContext`n, -0.08, $CellContext`v$$], 
               $CellContext`taT[$CellContext`n, -0.08, $CellContext`v$$]}, {
               $CellContext`xaT[$CellContext`n, 
                Plus[0.08], $CellContext`v$$], 
               $CellContext`taT[$CellContext`n, 
                Plus[0.08], $CellContext`v$$]}}]}, {$CellContext`n, 1, 7}], 
          If[$CellContext`sol$$, {
            Darker[Red], 
            Line[{{0, 0}, {7, 7}}], 
            Text[
             Style["c", {
               Darker[Red], Bold, 18}], {6.85, 6.65}]}], Blue, Dashed, 
          Line[{$CellContext`pta$$, {
             Part[$CellContext`pta$$, 1], 0}}], 
          Line[{$CellContext`pta$$, {0, 
             Part[$CellContext`pta$$, 2]}}], 
          Darker[Green], Dashed, 
          Line[{$CellContext`pta$$, {
             $CellContext`xaT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$], 
             $CellContext`taT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$]}}], 
          PointSize[0.015], 
          Point[{
            $CellContext`xaT[
             $CellContext`xbT[
              Part[$CellContext`pta$$, 1], 
              Part[$CellContext`pta$$, 2], $CellContext`v$$], 
             0, $CellContext`v$$], 
            $CellContext`taT[
             $CellContext`xbT[
              Part[$CellContext`pta$$, 1], 
              Part[$CellContext`pta$$, 2], $CellContext`v$$], 
             0, $CellContext`v$$]}], 
          Line[{$CellContext`pta$$, {
             $CellContext`xaT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$], 
             $CellContext`taT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$]}}], 
          PointSize[0.015], 
          Point[{
            $CellContext`xaT[0, 
             $CellContext`tbT[
              Part[$CellContext`pta$$, 1], 
              
              Part[$CellContext`pta$$, 
               2], $CellContext`v$$], $CellContext`v$$], 
            $CellContext`taT[0, 
             $CellContext`tbT[
              Part[$CellContext`pta$$, 1], 
              
              Part[$CellContext`pta$$, 
               2], $CellContext`v$$], $CellContext`v$$]}], 
          Line[{$CellContext`pta$$, {0, 
             Part[$CellContext`pta$$, 2]}}], 
          If[$CellContext`shw$$ == 2, {
            Darker[Green], 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{{0, 0}, {
               $CellContext`xaT[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                0, $CellContext`v$$], 
               $CellContext`taT[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                0, $CellContext`v$$]}}], Blue, 
            Line[{{0, 0.03}, {
               $CellContext`xaT[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                0, $CellContext`v$$], 0.03}}]}], 
          If[$CellContext`shw$$ == 3, {
            Darker[Green], 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{{0, 0}, {
               $CellContext`xaT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
            Line[{{0.03, 0}, {0.03, 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}]}], 
          If[$CellContext`shw$$ == 4, {
            Darker[Green], 
            Thickness[0.006], Dashed, 
            Line[{$CellContext`pta$$, {
               $CellContext`xaT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], 
            Line[{{0, 
               Part[$CellContext`pta$$, 2]}, {
               $CellContext`xaT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{{
               $CellContext`xaT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}, {
               $CellContext`xaT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{$CellContext`pta$$, {0, 
               Part[$CellContext`pta$$, 2]}}]}], 
          Opacity[1], White, 
          Rectangle[{-0.5, 7.2}, {7.5, 10.2}], 
          Text[
           Style["Lorentz Transformation", {Black, 24}], {3.5, 9.8}], 
          EdgeForm[
           Directive[Thick, Blue]], 
          Rectangle[{0, 7.8}, {3.4, 9.5}], 
          Opacity[0.2], Blue, 
          Rectangle[{0, 9.1}, {3.4, 9.5}], 
          Opacity[1], White, 
          Text[
           Style["Static FoR", {Blue, Bold, 18}], {1.7, 9.3}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(x\), \(A\)]\) = ", 
             ToString[
              NumberForm[
               Part[$CellContext`pta$$, 1], {3, 2}]], " light seconds"], {
            Blue, 16}], {1.7, 8.8}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(t\), \(A\)]\) = ", 
             ToString[
              NumberForm[
               Part[$CellContext`pta$$, 2], {3, 2}]], " seconds"], {
            Blue, 16}], {1.5, 8.5}], 
          If[$CellContext`shw$$ == 2, 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(l\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], {3, 2}]], " light seconds"], {
             Blue, 16}], {1.74, 8.1}]], 
          If[$CellContext`shw$$ == 3, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], {3, 2}]], 
              " seconds"], {Blue, 16}], {1.5, 8.1}]], 
          If[$CellContext`shw$$ == 4, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
              ToString[
               NumberForm[0, {3, 2}]], " seconds"], {Blue, 16}], {1.5, 8.1}]], 
          EdgeForm[
           Directive[Thick, 
            Darker[Green]]], 
          Rectangle[{3.5, 7.8}, {6.9, 9.5}], 
          Opacity[0.2], 
          Darker[Green], 
          Rectangle[{3.5, 9.1}, {6.9, 9.5}], 
          Opacity[1], White, 
          Text[
           Style[
            StringJoin["Moving FoR v = ", 
             ToString[
              NumberForm[$CellContext`v$$, {3, 2}]], " c"], {
             Darker[Green], Bold, 18}], {5.2, 9.3}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(x\), \(B\)]\) = ", 
             ToString[
              NumberForm[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
             " light seconds"], {
             Darker[Green], 16}], {5.2, 8.8}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(t\), \(B\)]\) = ", 
             ToString[
              NumberForm[
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
             " seconds"], {
             Darker[Green], 16}], {5, 8.5}], 
          If[$CellContext`shw$$ == 2, 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(l\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " light seconds"], {
              Darker[Green], 16}], {5.24, 8.1}]], 
          If[$CellContext`shw$$ == 3, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5., 8.1}]], 
          If[$CellContext`shw$$ == 4, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
              ToString[
               NumberForm[$CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$] - $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5., 8.1}]], 
          Text[
           Style["\!\(\*SubscriptBox[\(t\), \(A\)]\)", {Blue, 16}], {0.2, 
           7.5}], 
          Text[
           Style["\!\(\*SubscriptBox[\(t\), \(B\)]\)", {
             Darker[Green], 16}], {$CellContext`xaT[
             0, 7/$CellContext`\[Gamma][$CellContext`v$$], $CellContext`v$$] + 
            0.5, 7.}], 
          Text[
           Style["\!\(\*SubscriptBox[\(x\), \(B\)]\)", {
             Darker[Green], 16}], {
           6.8, $CellContext`loS[7, 0, $CellContext`v$$] + 0.5}]}, 
        AspectRatio -> 11/7, PlotRange -> {{0, 7}, {0, 10}}, ImageSize -> 
        500], "Specifications" :> {{{$CellContext`v$$, 0.5, "velocity"}, 0.01,
          0.85}, {{$CellContext`pta$$, {3, 3}}, {0, 0}, {7, 7}, ControlType -> 
         Locator}, {{$CellContext`shw$$, 1, "Show:"}, {
         1 -> "coordinates only", 2 -> "length contraction", 3 -> 
          "time dilation", 4 -> "relativity of simultaneity"}, ControlType -> 
         PopupMenu}, {{$CellContext`sol$$, False, 
          "speed of light worldline"}, {True, False}, ControlType -> 
         Checkbox}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{555., {446., 451.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`loL[
         Pattern[$CellContext`xa, 
          Blank[]], 
         Pattern[$CellContext`xb, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := $CellContext`xa/$CellContext`v - \
$CellContext`xb/($CellContext`\[Gamma][$CellContext`v] $CellContext`v), \
$CellContext`\[Gamma][
         Pattern[$CellContext`v, 
          Blank[]]] := 1/Sqrt[1 - $CellContext`v^2/1], $CellContext`loS[
         Pattern[$CellContext`xa, 
          Blank[]], 
         Pattern[$CellContext`tb, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := $CellContext`tb/$CellContext`\[Gamma][$CellContext`v] + \
($CellContext`v/1^2) $CellContext`xa, $CellContext`xaT[
         Pattern[$CellContext`xb, 
          Blank[]], 
         Pattern[$CellContext`tb, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := $CellContext`\[Gamma][$CellContext`v] ($CellContext`xb + \
$CellContext`v $CellContext`tb), $CellContext`taT[
         Pattern[$CellContext`xb, 
          Blank[]], 
         Pattern[$CellContext`tb, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := $CellContext`\[Gamma][$CellContext`v] ($CellContext`tb + \
$CellContext`v $CellContext`xb), $CellContext`xbT[
         Pattern[$CellContext`xa, 
          Blank[]], 
         Pattern[$CellContext`ta, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := $CellContext`\[Gamma][$CellContext`v] ($CellContext`xa - \
$CellContext`v $CellContext`ta), $CellContext`tbT[
         Pattern[$CellContext`xa, 
          Blank[]], 
         Pattern[$CellContext`ta, 
          Blank[]], 
         Pattern[$CellContext`v, 
          
          Blank[]]] := $CellContext`\[Gamma][$CellContext`v] ($CellContext`ta - \
$CellContext`v $CellContext`xa)}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5887837050895386`*^9},
 CellID->237248868]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateCaptionSection"],

Cell["\<\
Lorentz transformation is time-space coordinate transformation between the \
static (A) and moving (B) frame of reference in Einstein special theory of \
relativity. It is usefull to draw spacetime diagrams of both frames of \
reference into one plot with x axis in light seconds units. Than we can \
easily study all the basic phenomena of special theory of relativity (Lorentz \
transformation, length contraction, time dilation and relativity of \
simultaneity) in such combined spacetime diagram.  \
\>", "ManipulateCaption",
 CellChangeTimes->{{3.577982050064993*^9, 3.5779821745264378`*^9}, {
  3.57798221045503*^9, 3.5779826994619255`*^9}, {3.577985157388694*^9, 
  3.5779851646374187`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ThumbnailSection"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`pta$$ = {3, 3}, $CellContext`shw$$ = 
    1, $CellContext`sol$$ = True, $CellContext`v$$ = 0.5, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`v$$], 0.5, "velocity"}, 0.01, 0.85}, {{
       Hold[$CellContext`pta$$], {3, 3}}, {0, 0}, {7, 7}}, {{
       Hold[$CellContext`shw$$], 1, "Show:"}, {
      1 -> "coordinates only", 2 -> "length contraction", 3 -> 
       "time dilation", 4 -> "relativity of simultaneity"}}, {{
       Hold[$CellContext`sol$$], True, "speed of light worldline"}, {
      True, False}}}, Typeset`size$$ = {500., {373., 377.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`v$86604$$ = 0, $CellContext`pta$86605$$ = {0, 
    0}, $CellContext`shw$86606$$ = False, $CellContext`sol$86607$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`pta$$ = {3, 3}, $CellContext`shw$$ = 
        1, $CellContext`sol$$ = True, $CellContext`v$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`v$$, $CellContext`v$86604$$, 0], 
        Hold[$CellContext`pta$$, $CellContext`pta$86605$$, {0, 0}], 
        Hold[$CellContext`shw$$, $CellContext`shw$86606$$, False], 
        Hold[$CellContext`sol$$, $CellContext`sol$86607$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Evaluate[
         Flatten[{
           $CellContext`loL[$CellContext`xa, 0, $CellContext`v$$], 
           $CellContext`loS[$CellContext`xa, 0, $CellContext`v$$], 
           Table[
            $CellContext`loL[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}], 
           Table[
            $CellContext`loS[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}]}]], {$CellContext`xa, 0, 7},
         PlotStyle -> Table[
          Directive[
           Darker[Green], 
           If[$CellContext`n <= 2, Thick, 
            Thickness[0.0001]], 
           If[$CellContext`n <= 2, 
            Dashing[{}], Dotted]], {$CellContext`n, 84}], GridLines -> {
          Range[7], 
          Range[7]}, GridLinesStyle -> Directive[Blue, Thin, Dotted], 
        AxesStyle -> Directive[Blue, Thick], 
        AxesLabel -> {"\!\(\*SubscriptBox[\(x\), \(A\)]\)"}, Ticks -> {
          Range[7], 
          Range[7]}, LabelStyle -> 16, Epilog -> {
          Table[{
            Text[
             Style[$CellContext`n, {
               Darker[Green], 16}], {$CellContext`xaT[
               0, $CellContext`n, $CellContext`v$$] + 0.2, 
              $CellContext`taT[0, $CellContext`n, $CellContext`v$$]}], 
            Darker[Green], 
            Dashing[{}], 
            Line[{{
               $CellContext`xaT[-0.08, $CellContext`n, $CellContext`v$$], 
               $CellContext`taT[-0.08, $CellContext`n, $CellContext`v$$]}, {
               $CellContext`xaT[
                Plus[0.08], $CellContext`n, $CellContext`v$$], 
               $CellContext`taT[
                Plus[
                0.08], $CellContext`n, $CellContext`v$$]}}]}, {$CellContext`n,
             1, 7}], 
          Table[{
            Text[
             Style[$CellContext`n, {
               Darker[Green], 16}], {
              $CellContext`xaT[$CellContext`n, 
               0, $CellContext`v$$], $CellContext`taT[$CellContext`n, 
                0, $CellContext`v$$] + 0.2}], 
            Darker[Green], 
            Dashing[{}], 
            Line[{{
               $CellContext`xaT[$CellContext`n, -0.08, $CellContext`v$$], 
               $CellContext`taT[$CellContext`n, -0.08, $CellContext`v$$]}, {
               $CellContext`xaT[$CellContext`n, 
                Plus[0.08], $CellContext`v$$], 
               $CellContext`taT[$CellContext`n, 
                Plus[0.08], $CellContext`v$$]}}]}, {$CellContext`n, 1, 7}], 
          If[$CellContext`sol$$, {
            Darker[Red], 
            Line[{{0, 0}, {7, 7}}], 
            Text[
             Style["c", {
               Darker[Red], Bold, 18}], {6.85, 6.65}]}], Blue, Dashed, 
          Line[{$CellContext`pta$$, {
             Part[$CellContext`pta$$, 1], 0}}], 
          Line[{$CellContext`pta$$, {0, 
             Part[$CellContext`pta$$, 2]}}], 
          Darker[Green], Dashed, 
          Line[{$CellContext`pta$$, {
             $CellContext`xaT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$], 
             $CellContext`taT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$]}}], 
          PointSize[0.015], 
          Point[{
            $CellContext`xaT[
             $CellContext`xbT[
              Part[$CellContext`pta$$, 1], 
              Part[$CellContext`pta$$, 2], $CellContext`v$$], 
             0, $CellContext`v$$], 
            $CellContext`taT[
             $CellContext`xbT[
              Part[$CellContext`pta$$, 1], 
              Part[$CellContext`pta$$, 2], $CellContext`v$$], 
             0, $CellContext`v$$]}], 
          Line[{$CellContext`pta$$, {
             $CellContext`xaT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$], 
             $CellContext`taT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$]}}], 
          PointSize[0.015], 
          Point[{
            $CellContext`xaT[0, 
             $CellContext`tbT[
              Part[$CellContext`pta$$, 1], 
              
              Part[$CellContext`pta$$, 
               2], $CellContext`v$$], $CellContext`v$$], 
            $CellContext`taT[0, 
             $CellContext`tbT[
              Part[$CellContext`pta$$, 1], 
              
              Part[$CellContext`pta$$, 
               2], $CellContext`v$$], $CellContext`v$$]}], 
          Line[{$CellContext`pta$$, {0, 
             Part[$CellContext`pta$$, 2]}}], 
          If[$CellContext`shw$$ == 2, {
            Darker[Green], 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{{0, 0}, {
               $CellContext`xaT[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                0, $CellContext`v$$], 
               $CellContext`taT[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                0, $CellContext`v$$]}}], Blue, 
            Line[{{0, 0.03}, {
               $CellContext`xaT[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                0, $CellContext`v$$], 0.03}}]}], 
          If[$CellContext`shw$$ == 3, {
            Darker[Green], 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{{0, 0}, {
               $CellContext`xaT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
            Line[{{0.03, 0}, {0.03, 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}]}], 
          If[$CellContext`shw$$ == 4, {
            Darker[Green], 
            Thickness[0.006], Dashed, 
            Line[{$CellContext`pta$$, {
               $CellContext`xaT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], 
            Line[{{0, 
               Part[$CellContext`pta$$, 2]}, {
               $CellContext`xaT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{{
               $CellContext`xaT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[0, 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}, {
               $CellContext`xaT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$], 
               $CellContext`taT[0, 
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 
                 Part[$CellContext`pta$$, 
                  2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
            Thickness[0.01], 
            Dashing[{}], 
            Line[{$CellContext`pta$$, {0, 
               Part[$CellContext`pta$$, 2]}}]}], 
          Opacity[1], White, 
          Rectangle[{-0.5, 7.2}, {7.5, 10.2}], 
          Text[
           Style["Lorentz Transformation", {Black, 24}], {3.5, 9.8}], 
          EdgeForm[
           Directive[Thick, Blue]], 
          Rectangle[{0, 7.8}, {3.4, 9.5}], 
          Opacity[0.2], Blue, 
          Rectangle[{0, 9.1}, {3.4, 9.5}], 
          Opacity[1], White, 
          Text[
           Style["Static FoR", {Blue, Bold, 18}], {1.7, 9.3}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(x\), \(A\)]\) = ", 
             ToString[
              NumberForm[
               Part[$CellContext`pta$$, 1], {3, 2}]], " light seconds"], {
            Blue, 16}], {1.7, 8.8}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(t\), \(A\)]\) = ", 
             ToString[
              NumberForm[
               Part[$CellContext`pta$$, 2], {3, 2}]], " seconds"], {
            Blue, 16}], {1.5, 8.5}], 
          If[$CellContext`shw$$ == 2, 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(l\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], {3, 2}]], " light seconds"], {
             Blue, 16}], {1.74, 8.1}]], 
          If[$CellContext`shw$$ == 3, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], {3, 2}]], 
              " seconds"], {Blue, 16}], {1.5, 8.1}]], 
          If[$CellContext`shw$$ == 4, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
              ToString[
               NumberForm[0, {3, 2}]], " seconds"], {Blue, 16}], {1.5, 8.1}]], 
          EdgeForm[
           Directive[Thick, 
            Darker[Green]]], 
          Rectangle[{3.5, 7.8}, {6.9, 9.5}], 
          Opacity[0.2], 
          Darker[Green], 
          Rectangle[{3.5, 9.1}, {6.9, 9.5}], 
          Opacity[1], White, 
          Text[
           Style[
            StringJoin["Moving FoR v = ", 
             ToString[
              NumberForm[$CellContext`v$$, {3, 2}]], " c"], {
             Darker[Green], Bold, 18}], {5.2, 9.3}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(x\), \(B\)]\) = ", 
             ToString[
              NumberForm[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
             " light seconds"], {
             Darker[Green], 16}], {5.2, 8.8}], 
          Text[
           Style[
            StringJoin["\!\(\*SubscriptBox[\(t\), \(B\)]\) = ", 
             ToString[
              NumberForm[
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
             " seconds"], {
             Darker[Green], 16}], {5, 8.5}], 
          If[$CellContext`shw$$ == 2, 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(l\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " light seconds"], {
              Darker[Green], 16}], {5.24, 8.1}]], 
          If[$CellContext`shw$$ == 3, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5., 8.1}]], 
          If[$CellContext`shw$$ == 4, 
           Text[
            Style[
             StringJoin[
             "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
              ToString[
               NumberForm[$CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$] - $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5., 8.1}]], 
          Text[
           Style["\!\(\*SubscriptBox[\(t\), \(A\)]\)", {Blue, 16}], {0.2, 
           7.5}], 
          Text[
           Style["\!\(\*SubscriptBox[\(t\), \(B\)]\)", {
             Darker[Green], 16}], {$CellContext`xaT[
             0, 7/$CellContext`\[Gamma][$CellContext`v$$], $CellContext`v$$] + 
            0.5, 7.}], 
          Text[
           Style["\!\(\*SubscriptBox[\(x\), \(B\)]\)", {
             Darker[Green], 16}], {
           6.8, $CellContext`loS[7, 0, $CellContext`v$$] + 0.5}]}, 
        AspectRatio -> 11/7, PlotRange -> {{0, 7}, {0, 10}}, ImageSize -> 
        500], "Specifications" :> {{{$CellContext`v$$, 0.5, "velocity"}, 0.01,
          0.85}, {{$CellContext`pta$$, {3, 3}}, {0, 0}, {7, 7}, ControlType -> 
         Locator}, {{$CellContext`shw$$, 1, "Show:"}, {
         1 -> "coordinates only", 2 -> "length contraction", 3 -> 
          "time dilation", 4 -> "relativity of simultaneity"}, ControlType -> 
         PopupMenu}, {{$CellContext`sol$$, True, 
          "speed of light worldline"}, {True, False}, ControlType -> 
         Checkbox}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{555., {446., 451.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->2339421]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SnapshotsSection"],

Cell[BoxData[
 RowBox[{
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`pta$$ = {6.355, 
     5.485}, $CellContext`shw$$ = 2, $CellContext`sol$$ = 
     True, $CellContext`v$$ = 0.7, Typeset`show$$ = True, 
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`v$$], 0.7, "velocity"}, 0.01, 0.85}, {{
        Hold[$CellContext`pta$$], {6.355, 5.485}}, {0, 0}, {7, 7}}, {{
        Hold[$CellContext`shw$$], 2, "Show:"}, {
       1 -> "coordinates only", 2 -> "length contraction", 3 -> 
        "time dilation", 4 -> "relativity of simultaneity"}}, {{
        Hold[$CellContext`sol$$], True, "speed of light worldline"}, {
       True, False}}}, Typeset`size$$ = {500., {373., 377.}}, 
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
     True, $CellContext`v$86673$$ = 0, $CellContext`pta$86674$$ = {0, 
     0}, $CellContext`shw$86675$$ = False, $CellContext`sol$86676$$ = False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`pta$$ = {6.355, 
          5.485}, $CellContext`shw$$ = 2, $CellContext`sol$$ = 
         True, $CellContext`v$$ = 0.7}, "ControllerVariables" :> {
         Hold[$CellContext`v$$, $CellContext`v$86673$$, 0], 
         Hold[$CellContext`pta$$, $CellContext`pta$86674$$, {0, 0}], 
         Hold[$CellContext`shw$$, $CellContext`shw$86675$$, False], 
         Hold[$CellContext`sol$$, $CellContext`sol$86676$$, False]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Plot[
         Evaluate[
          Flatten[{
            $CellContext`loL[$CellContext`xa, 0, $CellContext`v$$], 
            $CellContext`loS[$CellContext`xa, 0, $CellContext`v$$], 
            Table[
             $CellContext`loL[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}], 
            Table[
             $CellContext`loS[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}]}]], {$CellContext`xa, 0, 7},
          PlotStyle -> Table[
           Directive[
            Darker[Green], 
            If[$CellContext`n <= 2, Thick, 
             Thickness[0.0001]], 
            If[$CellContext`n <= 2, 
             Dashing[{}], Dotted]], {$CellContext`n, 84}], GridLines -> {
           Range[7], 
           Range[7]}, GridLinesStyle -> Directive[Blue, Thin, Dotted], 
         AxesStyle -> Directive[Blue, Thick], 
         AxesLabel -> {"\!\(\*SubscriptBox[\(x\), \(A\)]\)"}, Ticks -> {
           Range[7], 
           Range[7]}, LabelStyle -> 16, Epilog -> {
           Table[{
             Text[
              Style[$CellContext`n, {
                Darker[Green], 16}], {$CellContext`xaT[
                0, $CellContext`n, $CellContext`v$$] + 0.2, 
               $CellContext`taT[0, $CellContext`n, $CellContext`v$$]}], 
             Darker[Green], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[-0.08, $CellContext`n, $CellContext`v$$], 
                $CellContext`taT[-0.08, $CellContext`n, $CellContext`v$$]}, {
                $CellContext`xaT[
                 Plus[0.08], $CellContext`n, $CellContext`v$$], 
                $CellContext`taT[
                 Plus[
                 0.08], $CellContext`n, $CellContext`v$$]}}]}, \
{$CellContext`n, 1, 7}], 
           Table[{
             Text[
              Style[$CellContext`n, {
                Darker[Green], 16}], {
               $CellContext`xaT[$CellContext`n, 
                0, $CellContext`v$$], $CellContext`taT[$CellContext`n, 
                 0, $CellContext`v$$] + 0.2}], 
             Darker[Green], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[$CellContext`n, -0.08, $CellContext`v$$], 
                $CellContext`taT[$CellContext`n, -0.08, $CellContext`v$$]}, {
                $CellContext`xaT[$CellContext`n, 
                 Plus[0.08], $CellContext`v$$], 
                $CellContext`taT[$CellContext`n, 
                 Plus[0.08], $CellContext`v$$]}}]}, {$CellContext`n, 1, 7}], 
           If[$CellContext`sol$$, {
             Darker[Red], 
             Line[{{0, 0}, {7, 7}}], 
             Text[
              Style["c", {
                Darker[Red], Bold, 18}], {6.85, 6.65}]}], Blue, Dashed, 
           Line[{$CellContext`pta$$, {
              Part[$CellContext`pta$$, 1], 0}}], 
           Line[{$CellContext`pta$$, {0, 
              Part[$CellContext`pta$$, 2]}}], 
           Darker[Green], Dashed, 
           Line[{$CellContext`pta$$, {
              $CellContext`xaT[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], 
               0, $CellContext`v$$], 
              $CellContext`taT[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], 
               0, $CellContext`v$$]}}], 
           PointSize[0.015], 
           Point[{
             $CellContext`xaT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$], 
             $CellContext`taT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$]}], 
           Line[{$CellContext`pta$$, {
              $CellContext`xaT[0, 
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                
                Part[$CellContext`pta$$, 
                 2], $CellContext`v$$], $CellContext`v$$], 
              $CellContext`taT[0, 
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                
                Part[$CellContext`pta$$, 
                 2], $CellContext`v$$], $CellContext`v$$]}}], 
           PointSize[0.015], 
           Point[{
             $CellContext`xaT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$], 
             $CellContext`taT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$]}], 
           Line[{$CellContext`pta$$, {0, 
              Part[$CellContext`pta$$, 2]}}], 
           If[$CellContext`shw$$ == 2, {
             Darker[Green], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{0, 0}, {
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], 
                $CellContext`taT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$]}}], Blue, 
             Line[{{0, 0.03}, {
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], 0.03}}]}], 
           If[$CellContext`shw$$ == 3, {
             Darker[Green], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{0, 0}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
             Line[{{0.03, 0}, {0.03, 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}]}], 
           If[$CellContext`shw$$ == 4, {
             Darker[Green], 
             Thickness[0.006], Dashed, 
             Line[{$CellContext`pta$$, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], 
             Line[{{0, 
                Part[$CellContext`pta$$, 2]}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{$CellContext`pta$$, {0, 
                Part[$CellContext`pta$$, 2]}}]}], 
           Opacity[1], White, 
           Rectangle[{-0.5, 7.2}, {7.5, 10.2}], 
           Text[
            Style["Lorentz Transformation", {Black, 24}], {3.5, 9.8}], 
           EdgeForm[
            Directive[Thick, Blue]], 
           Rectangle[{0, 7.8}, {3.4, 9.5}], 
           Opacity[0.2], Blue, 
           Rectangle[{0, 9.1}, {3.4, 9.5}], 
           Opacity[1], White, 
           Text[
            Style["Static FoR", {Blue, Bold, 18}], {1.7, 9.3}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(x\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                Part[$CellContext`pta$$, 1], {3, 2}]], " light seconds"], {
             Blue, 16}], {1.7, 8.8}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(t\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                Part[$CellContext`pta$$, 2], {3, 2}]], " seconds"], {
             Blue, 16}], {1.5, 8.5}], 
           If[$CellContext`shw$$ == 2, 
            Text[
             Style[
              StringJoin["\!\(\*SubscriptBox[\(l\), \(A\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`xaT[
                  $CellContext`xbT[
                   Part[$CellContext`pta$$, 1], 
                   Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                  0, $CellContext`v$$], {3, 2}]], " light seconds"], {
              Blue, 16}], {1.74, 8.1}]], 
           If[$CellContext`shw$$ == 3, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`taT[0, 
                  $CellContext`tbT[
                   Part[$CellContext`pta$$, 1], 
                   
                   Part[$CellContext`pta$$, 
                    2], $CellContext`v$$], $CellContext`v$$], {3, 2}]], 
               " seconds"], {Blue, 16}], {1.5, 8.1}]], 
           If[$CellContext`shw$$ == 4, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
               ToString[
                NumberForm[0, {3, 2}]], " seconds"], {Blue, 16}], {1.5, 
             8.1}]], 
           EdgeForm[
            Directive[Thick, 
             Darker[Green]]], 
           Rectangle[{3.5, 7.8}, {6.9, 9.5}], 
           Opacity[0.2], 
           Darker[Green], 
           Rectangle[{3.5, 9.1}, {6.9, 9.5}], 
           Opacity[1], White, 
           Text[
            Style[
             StringJoin["Moving FoR v = ", 
              ToString[
               NumberForm[$CellContext`v$$, {3, 2}]], " c"], {
              Darker[Green], Bold, 18}], {5.2, 9.3}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(x\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " light seconds"], {
              Darker[Green], 16}], {5.2, 8.8}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(t\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5, 8.5}], 
           If[$CellContext`shw$$ == 2, 
            Text[
             Style[
              StringJoin["\!\(\*SubscriptBox[\(l\), \(B\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " light seconds"], {
               Darker[Green], 16}], {5.24, 8.1}]], 
           If[$CellContext`shw$$ == 3, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " seconds"], {
               Darker[Green], 16}], {5., 8.1}]], 
           If[$CellContext`shw$$ == 4, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
               ToString[
                NumberForm[$CellContext`tbT[0, 
                   
                   Part[$CellContext`pta$$, 
                    2], $CellContext`v$$] - $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " seconds"], {
               Darker[Green], 16}], {5., 8.1}]], 
           Text[
            Style["\!\(\*SubscriptBox[\(t\), \(A\)]\)", {Blue, 16}], {0.2, 
            7.5}], 
           Text[
            Style["\!\(\*SubscriptBox[\(t\), \(B\)]\)", {
              Darker[Green], 16}], {$CellContext`xaT[
              0, 7/$CellContext`\[Gamma][$CellContext`v$$], $CellContext`v$$] + 
             0.5, 7.}], 
           Text[
            Style["\!\(\*SubscriptBox[\(x\), \(B\)]\)", {
              Darker[Green], 16}], {
            6.8, $CellContext`loS[7, 0, $CellContext`v$$] + 0.5}]}, 
         AspectRatio -> 11/7, PlotRange -> {{0, 7}, {0, 10}}, ImageSize -> 
         500], "Specifications" :> {{{$CellContext`v$$, 0.7, "velocity"}, 
          0.01, 0.85}, {{$CellContext`pta$$, {6.355, 5.485}}, {0, 0}, {7, 7}, 
          ControlType -> Locator}, {{$CellContext`shw$$, 2, "Show:"}, {
          1 -> "coordinates only", 2 -> "length contraction", 3 -> 
           "time dilation", 4 -> "relativity of simultaneity"}, ControlType -> 
          PopupMenu}, {{$CellContext`sol$$, True, 
           "speed of light worldline"}, {True, False}, ControlType -> 
          Checkbox}}, "Options" :> {}, 
       "DefaultOptions" :> {ControllerLinking -> True}],
      ImageSizeCache->{555., {446., 451.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     SynchronousInitialization->True,
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]], 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`pta$$ = {2.3850000000000002`, 
     3.335}, $CellContext`shw$$ = 3, $CellContext`sol$$ = 
     False, $CellContext`v$$ = 0.18300000000000002`, Typeset`show$$ = True, 
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`v$$], 0.5, "velocity"}, 0.01, 0.85}, {{
        Hold[$CellContext`pta$$], {3, 3}}, {0, 0}, {7, 7}}, {{
        Hold[$CellContext`shw$$], 1, "Show:"}, {
       1 -> "coordinates only", 2 -> "length contraction", 3 -> 
        "time dilation", 4 -> "relativity of simultaneity"}}, {{
        Hold[$CellContext`sol$$], True, "speed of light worldline"}, {
       True, False}}}, Typeset`size$$ = {500., {373., 377.}}, 
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
     True, $CellContext`v$86535$$ = 0, $CellContext`pta$86536$$ = {0, 
     0}, $CellContext`shw$86537$$ = False, $CellContext`sol$86538$$ = False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`pta$$ = {3, 3}, $CellContext`shw$$ = 
         1, $CellContext`sol$$ = True, $CellContext`v$$ = 0.5}, 
       "ControllerVariables" :> {
         Hold[$CellContext`v$$, $CellContext`v$86535$$, 0], 
         Hold[$CellContext`pta$$, $CellContext`pta$86536$$, {0, 0}], 
         Hold[$CellContext`shw$$, $CellContext`shw$86537$$, False], 
         Hold[$CellContext`sol$$, $CellContext`sol$86538$$, False]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Plot[
         Evaluate[
          Flatten[{
            $CellContext`loL[$CellContext`xa, 0, $CellContext`v$$], 
            $CellContext`loS[$CellContext`xa, 0, $CellContext`v$$], 
            Table[
             $CellContext`loL[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}], 
            Table[
             $CellContext`loS[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}]}]], {$CellContext`xa, 0, 7},
          PlotStyle -> Table[
           Directive[
            Darker[Green], 
            If[$CellContext`n <= 2, Thick, 
             Thickness[0.0001]], 
            If[$CellContext`n <= 2, 
             Dashing[{}], Dotted]], {$CellContext`n, 84}], GridLines -> {
           Range[7], 
           Range[7]}, GridLinesStyle -> Directive[Blue, Thin, Dotted], 
         AxesStyle -> Directive[Blue, Thick], 
         AxesLabel -> {"\!\(\*SubscriptBox[\(x\), \(A\)]\)"}, Ticks -> {
           Range[7], 
           Range[7]}, LabelStyle -> 16, Epilog -> {
           Table[{
             Text[
              Style[$CellContext`n, {
                Darker[Green], 16}], {$CellContext`xaT[
                0, $CellContext`n, $CellContext`v$$] + 0.2, 
               $CellContext`taT[0, $CellContext`n, $CellContext`v$$]}], 
             Darker[Green], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[-0.08, $CellContext`n, $CellContext`v$$], 
                $CellContext`taT[-0.08, $CellContext`n, $CellContext`v$$]}, {
                $CellContext`xaT[
                 Plus[0.08], $CellContext`n, $CellContext`v$$], 
                $CellContext`taT[
                 Plus[
                 0.08], $CellContext`n, $CellContext`v$$]}}]}, \
{$CellContext`n, 1, 7}], 
           Table[{
             Text[
              Style[$CellContext`n, {
                Darker[Green], 16}], {
               $CellContext`xaT[$CellContext`n, 
                0, $CellContext`v$$], $CellContext`taT[$CellContext`n, 
                 0, $CellContext`v$$] + 0.2}], 
             Darker[Green], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[$CellContext`n, -0.08, $CellContext`v$$], 
                $CellContext`taT[$CellContext`n, -0.08, $CellContext`v$$]}, {
                $CellContext`xaT[$CellContext`n, 
                 Plus[0.08], $CellContext`v$$], 
                $CellContext`taT[$CellContext`n, 
                 Plus[0.08], $CellContext`v$$]}}]}, {$CellContext`n, 1, 7}], 
           If[$CellContext`sol$$, {
             Darker[Red], 
             Line[{{0, 0}, {7, 7}}], 
             Text[
              Style["c", {
                Darker[Red], Bold, 18}], {6.85, 6.65}]}], Blue, Dashed, 
           Line[{$CellContext`pta$$, {
              Part[$CellContext`pta$$, 1], 0}}], 
           Line[{$CellContext`pta$$, {0, 
              Part[$CellContext`pta$$, 2]}}], 
           Darker[Green], Dashed, 
           Line[{$CellContext`pta$$, {
              $CellContext`xaT[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], 
               0, $CellContext`v$$], 
              $CellContext`taT[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], 
               0, $CellContext`v$$]}}], 
           PointSize[0.015], 
           Point[{
             $CellContext`xaT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$], 
             $CellContext`taT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$]}], 
           Line[{$CellContext`pta$$, {
              $CellContext`xaT[0, 
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                
                Part[$CellContext`pta$$, 
                 2], $CellContext`v$$], $CellContext`v$$], 
              $CellContext`taT[0, 
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                
                Part[$CellContext`pta$$, 
                 2], $CellContext`v$$], $CellContext`v$$]}}], 
           PointSize[0.015], 
           Point[{
             $CellContext`xaT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$], 
             $CellContext`taT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$]}], 
           Line[{$CellContext`pta$$, {0, 
              Part[$CellContext`pta$$, 2]}}], 
           If[$CellContext`shw$$ == 2, {
             Darker[Green], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{0, 0}, {
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], 
                $CellContext`taT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$]}}], Blue, 
             Line[{{0, 0.03}, {
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], 0.03}}]}], 
           If[$CellContext`shw$$ == 3, {
             Darker[Green], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{0, 0}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
             Line[{{0.03, 0}, {0.03, 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}]}], 
           If[$CellContext`shw$$ == 4, {
             Darker[Green], 
             Thickness[0.006], Dashed, 
             Line[{$CellContext`pta$$, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], 
             Line[{{0, 
                Part[$CellContext`pta$$, 2]}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{$CellContext`pta$$, {0, 
                Part[$CellContext`pta$$, 2]}}]}], 
           Opacity[1], White, 
           Rectangle[{-0.5, 7.2}, {7.5, 10.2}], 
           Text[
            Style["Lorentz Transformation", {Black, 24}], {3.5, 9.8}], 
           EdgeForm[
            Directive[Thick, Blue]], 
           Rectangle[{0, 7.8}, {3.4, 9.5}], 
           Opacity[0.2], Blue, 
           Rectangle[{0, 9.1}, {3.4, 9.5}], 
           Opacity[1], White, 
           Text[
            Style["Static FoR", {Blue, Bold, 18}], {1.7, 9.3}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(x\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                Part[$CellContext`pta$$, 1], {3, 2}]], " light seconds"], {
             Blue, 16}], {1.7, 8.8}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(t\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                Part[$CellContext`pta$$, 2], {3, 2}]], " seconds"], {
             Blue, 16}], {1.5, 8.5}], 
           If[$CellContext`shw$$ == 2, 
            Text[
             Style[
              StringJoin["\!\(\*SubscriptBox[\(l\), \(A\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`xaT[
                  $CellContext`xbT[
                   Part[$CellContext`pta$$, 1], 
                   Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                  0, $CellContext`v$$], {3, 2}]], " light seconds"], {
              Blue, 16}], {1.74, 8.1}]], 
           If[$CellContext`shw$$ == 3, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`taT[0, 
                  $CellContext`tbT[
                   Part[$CellContext`pta$$, 1], 
                   
                   Part[$CellContext`pta$$, 
                    2], $CellContext`v$$], $CellContext`v$$], {3, 2}]], 
               " seconds"], {Blue, 16}], {1.5, 8.1}]], 
           If[$CellContext`shw$$ == 4, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
               ToString[
                NumberForm[0, {3, 2}]], " seconds"], {Blue, 16}], {1.5, 
             8.1}]], 
           EdgeForm[
            Directive[Thick, 
             Darker[Green]]], 
           Rectangle[{3.5, 7.8}, {6.9, 9.5}], 
           Opacity[0.2], 
           Darker[Green], 
           Rectangle[{3.5, 9.1}, {6.9, 9.5}], 
           Opacity[1], White, 
           Text[
            Style[
             StringJoin["Moving FoR v = ", 
              ToString[
               NumberForm[$CellContext`v$$, {3, 2}]], " c"], {
              Darker[Green], Bold, 18}], {5.2, 9.3}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(x\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " light seconds"], {
              Darker[Green], 16}], {5.2, 8.8}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(t\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5, 8.5}], 
           If[$CellContext`shw$$ == 2, 
            Text[
             Style[
              StringJoin["\!\(\*SubscriptBox[\(l\), \(B\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " light seconds"], {
               Darker[Green], 16}], {5.24, 8.1}]], 
           If[$CellContext`shw$$ == 3, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " seconds"], {
               Darker[Green], 16}], {5., 8.1}]], 
           If[$CellContext`shw$$ == 4, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
               ToString[
                NumberForm[$CellContext`tbT[0, 
                   
                   Part[$CellContext`pta$$, 
                    2], $CellContext`v$$] - $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " seconds"], {
               Darker[Green], 16}], {5., 8.1}]], 
           Text[
            Style["\!\(\*SubscriptBox[\(t\), \(A\)]\)", {Blue, 16}], {0.2, 
            7.5}], 
           Text[
            Style["\!\(\*SubscriptBox[\(t\), \(B\)]\)", {
              Darker[Green], 16}], {$CellContext`xaT[
              0, 7/$CellContext`\[Gamma][$CellContext`v$$], $CellContext`v$$] + 
             0.5, 7.}], 
           Text[
            Style["\!\(\*SubscriptBox[\(x\), \(B\)]\)", {
              Darker[Green], 16}], {
            6.8, $CellContext`loS[7, 0, $CellContext`v$$] + 0.5}]}, 
         AspectRatio -> 11/7, PlotRange -> {{0, 7}, {0, 10}}, ImageSize -> 
         500], "Specifications" :> {{{$CellContext`v$$, 0.5, "velocity"}, 
          0.01, 0.85}, {{$CellContext`pta$$, {3, 3}}, {0, 0}, {7, 7}, 
          ControlType -> Locator}, {{$CellContext`shw$$, 1, "Show:"}, {
          1 -> "coordinates only", 2 -> "length contraction", 3 -> 
           "time dilation", 4 -> "relativity of simultaneity"}, ControlType -> 
          PopupMenu}, {{$CellContext`sol$$, True, 
           "speed of light worldline"}, {True, False}, ControlType -> 
          Checkbox}}, "Options" :> {}, 
       "DefaultOptions" :> {ControllerLinking -> True}],
      ImageSizeCache->{555., {446., 451.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     SynchronousInitialization->True,
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]], 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`pta$$ = {5.325, 3.98}, $CellContext`shw$$ =
      4, $CellContext`sol$$ = True, $CellContext`v$$ = 0.601, Typeset`show$$ =
      True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`v$$], 0.5, "velocity"}, 0.01, 0.85}, {{
        Hold[$CellContext`pta$$], {3, 3}}, {0, 0}, {7, 7}}, {{
        Hold[$CellContext`shw$$], 1, "Show:"}, {
       1 -> "coordinates only", 2 -> "length contraction", 3 -> 
        "time dilation", 4 -> "relativity of simultaneity"}}, {{
        Hold[$CellContext`sol$$], True, "speed of light worldline"}, {
       True, False}}}, Typeset`size$$ = {500., {373., 377.}}, 
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
     True, $CellContext`v$86535$$ = 0, $CellContext`pta$86536$$ = {0, 
     0}, $CellContext`shw$86537$$ = False, $CellContext`sol$86538$$ = False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`pta$$ = {3, 3}, $CellContext`shw$$ = 
         1, $CellContext`sol$$ = True, $CellContext`v$$ = 0.5}, 
       "ControllerVariables" :> {
         Hold[$CellContext`v$$, $CellContext`v$86535$$, 0], 
         Hold[$CellContext`pta$$, $CellContext`pta$86536$$, {0, 0}], 
         Hold[$CellContext`shw$$, $CellContext`shw$86537$$, False], 
         Hold[$CellContext`sol$$, $CellContext`sol$86538$$, False]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Plot[
         Evaluate[
          Flatten[{
            $CellContext`loL[$CellContext`xa, 0, $CellContext`v$$], 
            $CellContext`loS[$CellContext`xa, 0, $CellContext`v$$], 
            Table[
             $CellContext`loL[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}], 
            Table[
             $CellContext`loS[$CellContext`xa, $CellContext`xb, \
$CellContext`v$$], {$CellContext`xb, -20, 20, 1}]}]], {$CellContext`xa, 0, 7},
          PlotStyle -> Table[
           Directive[
            Darker[Green], 
            If[$CellContext`n <= 2, Thick, 
             Thickness[0.0001]], 
            If[$CellContext`n <= 2, 
             Dashing[{}], Dotted]], {$CellContext`n, 84}], GridLines -> {
           Range[7], 
           Range[7]}, GridLinesStyle -> Directive[Blue, Thin, Dotted], 
         AxesStyle -> Directive[Blue, Thick], 
         AxesLabel -> {"\!\(\*SubscriptBox[\(x\), \(A\)]\)"}, Ticks -> {
           Range[7], 
           Range[7]}, LabelStyle -> 16, Epilog -> {
           Table[{
             Text[
              Style[$CellContext`n, {
                Darker[Green], 16}], {$CellContext`xaT[
                0, $CellContext`n, $CellContext`v$$] + 0.2, 
               $CellContext`taT[0, $CellContext`n, $CellContext`v$$]}], 
             Darker[Green], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[-0.08, $CellContext`n, $CellContext`v$$], 
                $CellContext`taT[-0.08, $CellContext`n, $CellContext`v$$]}, {
                $CellContext`xaT[
                 Plus[0.08], $CellContext`n, $CellContext`v$$], 
                $CellContext`taT[
                 Plus[
                 0.08], $CellContext`n, $CellContext`v$$]}}]}, \
{$CellContext`n, 1, 7}], 
           Table[{
             Text[
              Style[$CellContext`n, {
                Darker[Green], 16}], {
               $CellContext`xaT[$CellContext`n, 
                0, $CellContext`v$$], $CellContext`taT[$CellContext`n, 
                 0, $CellContext`v$$] + 0.2}], 
             Darker[Green], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[$CellContext`n, -0.08, $CellContext`v$$], 
                $CellContext`taT[$CellContext`n, -0.08, $CellContext`v$$]}, {
                $CellContext`xaT[$CellContext`n, 
                 Plus[0.08], $CellContext`v$$], 
                $CellContext`taT[$CellContext`n, 
                 Plus[0.08], $CellContext`v$$]}}]}, {$CellContext`n, 1, 7}], 
           If[$CellContext`sol$$, {
             Darker[Red], 
             Line[{{0, 0}, {7, 7}}], 
             Text[
              Style["c", {
                Darker[Red], Bold, 18}], {6.85, 6.65}]}], Blue, Dashed, 
           Line[{$CellContext`pta$$, {
              Part[$CellContext`pta$$, 1], 0}}], 
           Line[{$CellContext`pta$$, {0, 
              Part[$CellContext`pta$$, 2]}}], 
           Darker[Green], Dashed, 
           Line[{$CellContext`pta$$, {
              $CellContext`xaT[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], 
               0, $CellContext`v$$], 
              $CellContext`taT[
               $CellContext`xbT[
                Part[$CellContext`pta$$, 1], 
                Part[$CellContext`pta$$, 2], $CellContext`v$$], 
               0, $CellContext`v$$]}}], 
           PointSize[0.015], 
           Point[{
             $CellContext`xaT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$], 
             $CellContext`taT[
              $CellContext`xbT[
               Part[$CellContext`pta$$, 1], 
               Part[$CellContext`pta$$, 2], $CellContext`v$$], 
              0, $CellContext`v$$]}], 
           Line[{$CellContext`pta$$, {
              $CellContext`xaT[0, 
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                
                Part[$CellContext`pta$$, 
                 2], $CellContext`v$$], $CellContext`v$$], 
              $CellContext`taT[0, 
               $CellContext`tbT[
                Part[$CellContext`pta$$, 1], 
                
                Part[$CellContext`pta$$, 
                 2], $CellContext`v$$], $CellContext`v$$]}}], 
           PointSize[0.015], 
           Point[{
             $CellContext`xaT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$], 
             $CellContext`taT[0, 
              $CellContext`tbT[
               Part[$CellContext`pta$$, 1], 
               
               Part[$CellContext`pta$$, 
                2], $CellContext`v$$], $CellContext`v$$]}], 
           Line[{$CellContext`pta$$, {0, 
              Part[$CellContext`pta$$, 2]}}], 
           If[$CellContext`shw$$ == 2, {
             Darker[Green], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{0, 0}, {
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], 
                $CellContext`taT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$]}}], Blue, 
             Line[{{0, 0.03}, {
                $CellContext`xaT[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                 0, $CellContext`v$$], 0.03}}]}], 
           If[$CellContext`shw$$ == 3, {
             Darker[Green], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{0, 0}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
             Line[{{0.03, 0}, {0.03, 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}]}], 
           If[$CellContext`shw$$ == 4, {
             Darker[Green], 
             Thickness[0.006], Dashed, 
             Line[{$CellContext`pta$$, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], 
             Line[{{0, 
                Part[$CellContext`pta$$, 2]}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{{
                $CellContext`xaT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[0, 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}, {
                $CellContext`xaT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$], 
                $CellContext`taT[0, 
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  
                  Part[$CellContext`pta$$, 
                   2], $CellContext`v$$], $CellContext`v$$]}}], Blue, 
             Thickness[0.01], 
             Dashing[{}], 
             Line[{$CellContext`pta$$, {0, 
                Part[$CellContext`pta$$, 2]}}]}], 
           Opacity[1], White, 
           Rectangle[{-0.5, 7.2}, {7.5, 10.2}], 
           Text[
            Style["Lorentz Transformation", {Black, 24}], {3.5, 9.8}], 
           EdgeForm[
            Directive[Thick, Blue]], 
           Rectangle[{0, 7.8}, {3.4, 9.5}], 
           Opacity[0.2], Blue, 
           Rectangle[{0, 9.1}, {3.4, 9.5}], 
           Opacity[1], White, 
           Text[
            Style["Static FoR", {Blue, Bold, 18}], {1.7, 9.3}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(x\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                Part[$CellContext`pta$$, 1], {3, 2}]], " light seconds"], {
             Blue, 16}], {1.7, 8.8}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(t\), \(A\)]\) = ", 
              ToString[
               NumberForm[
                Part[$CellContext`pta$$, 2], {3, 2}]], " seconds"], {
             Blue, 16}], {1.5, 8.5}], 
           If[$CellContext`shw$$ == 2, 
            Text[
             Style[
              StringJoin["\!\(\*SubscriptBox[\(l\), \(A\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`xaT[
                  $CellContext`xbT[
                   Part[$CellContext`pta$$, 1], 
                   Part[$CellContext`pta$$, 2], $CellContext`v$$], 
                  0, $CellContext`v$$], {3, 2}]], " light seconds"], {
              Blue, 16}], {1.74, 8.1}]], 
           If[$CellContext`shw$$ == 3, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`taT[0, 
                  $CellContext`tbT[
                   Part[$CellContext`pta$$, 1], 
                   
                   Part[$CellContext`pta$$, 
                    2], $CellContext`v$$], $CellContext`v$$], {3, 2}]], 
               " seconds"], {Blue, 16}], {1.5, 8.1}]], 
           If[$CellContext`shw$$ == 4, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(A\)]\) = ", 
               ToString[
                NumberForm[0, {3, 2}]], " seconds"], {Blue, 16}], {1.5, 
             8.1}]], 
           EdgeForm[
            Directive[Thick, 
             Darker[Green]]], 
           Rectangle[{3.5, 7.8}, {6.9, 9.5}], 
           Opacity[0.2], 
           Darker[Green], 
           Rectangle[{3.5, 9.1}, {6.9, 9.5}], 
           Opacity[1], White, 
           Text[
            Style[
             StringJoin["Moving FoR v = ", 
              ToString[
               NumberForm[$CellContext`v$$, {3, 2}]], " c"], {
              Darker[Green], Bold, 18}], {5.2, 9.3}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(x\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`xbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " light seconds"], {
              Darker[Green], 16}], {5.2, 8.8}], 
           Text[
            Style[
             StringJoin["\!\(\*SubscriptBox[\(t\), \(B\)]\) = ", 
              ToString[
               NumberForm[
                $CellContext`tbT[
                 Part[$CellContext`pta$$, 1], 
                 Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
              " seconds"], {
              Darker[Green], 16}], {5, 8.5}], 
           If[$CellContext`shw$$ == 2, 
            Text[
             Style[
              StringJoin["\!\(\*SubscriptBox[\(l\), \(B\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`xbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " light seconds"], {
               Darker[Green], 16}], {5.24, 8.1}]], 
           If[$CellContext`shw$$ == 3, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
               ToString[
                NumberForm[
                 $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " seconds"], {
               Darker[Green], 16}], {5., 8.1}]], 
           If[$CellContext`shw$$ == 4, 
            Text[
             Style[
              StringJoin[
              "\!\(\*SubscriptBox[\(\[CapitalDelta]t\), \(B\)]\) = ", 
               ToString[
                NumberForm[$CellContext`tbT[0, 
                   
                   Part[$CellContext`pta$$, 
                    2], $CellContext`v$$] - $CellContext`tbT[
                  Part[$CellContext`pta$$, 1], 
                  Part[$CellContext`pta$$, 2], $CellContext`v$$], {3, 2}]], 
               " seconds"], {
               Darker[Green], 16}], {5., 8.1}]], 
           Text[
            Style["\!\(\*SubscriptBox[\(t\), \(A\)]\)", {Blue, 16}], {0.2, 
            7.5}], 
           Text[
            Style["\!\(\*SubscriptBox[\(t\), \(B\)]\)", {
              Darker[Green], 16}], {$CellContext`xaT[
              0, 7/$CellContext`\[Gamma][$CellContext`v$$], $CellContext`v$$] + 
             0.5, 7.}], 
           Text[
            Style["\!\(\*SubscriptBox[\(x\), \(B\)]\)", {
              Darker[Green], 16}], {
            6.8, $CellContext`loS[7, 0, $CellContext`v$$] + 0.5}]}, 
         AspectRatio -> 11/7, PlotRange -> {{0, 7}, {0, 10}}, ImageSize -> 
         500], "Specifications" :> {{{$CellContext`v$$, 0.5, "velocity"}, 
          0.01, 0.85}, {{$CellContext`pta$$, {3, 3}}, {0, 0}, {7, 7}, 
          ControlType -> Locator}, {{$CellContext`shw$$, 1, "Show:"}, {
          1 -> "coordinates only", 2 -> "length contraction", 3 -> 
           "time dilation", 4 -> "relativity of simultaneity"}, ControlType -> 
          PopupMenu}, {{$CellContext`sol$$, True, 
           "speed of light worldline"}, {True, False}, ControlType -> 
          Checkbox}}, "Options" :> {}, 
       "DefaultOptions" :> {ControllerLinking -> True}],
      ImageSizeCache->{555., {446., 451.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     SynchronousInitialization->True,
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}]], "Input",
 CellChangeTimes->{{3.577983482891261*^9, 3.5779834830392756`*^9}, 
   3.5779835607750483`*^9},
 CellID->167508588]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "DetailsSection"],

Cell["\<\
Lorentz transformation from frame of reference B which is moving with speed v \
in positive direction (usually to the right) to static frame of reference A \
is defined by equations:\
\>", "DetailNotes",
 CellChangeTimes->{{3.5779838141383824`*^9, 3.577983979375904*^9}, {
  3.5779840114451113`*^9, 3.5779841052784934`*^9}, {3.5779851266836233`*^9, 
  3.577985127835739*^9}},
 CellID->610034143],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "A"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "(", 
       RowBox[{
        SubscriptBox["x", "B"], "+", 
        RowBox[{"v", " ", 
         SubscriptBox["t", "B"]}]}], ")"}], "  ", "and", "  ", 
      SubscriptBox["t", "A"]}], "=", " ", 
     RowBox[{"\[Gamma]", "(", 
      RowBox[{
       SubscriptBox["t", "B"], "+", 
       RowBox[{
        FractionBox["v", 
         SuperscriptBox["c", "2"]], " ", 
        SubscriptBox["x", "B"]}]}], ")"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"where", " ", "Lorentz", " ", "factor", " ", "\[Gamma]"}], "=", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["v", "2"], 
        SuperscriptBox["c", "2"]]}]]]}]}], TraditionalForm]], "InlineMath",
 FormatType->"TraditionalForm"]], "DetailNotes",
 CellChangeTimes->{{3.5779838141383824`*^9, 3.577983979371904*^9}, {
  3.57798411604657*^9, 3.577984341348098*^9}, {3.5779843743063936`*^9, 
  3.5779843743143945`*^9}},
 CellID->3037942],

Cell["\<\
If we evaluate these equations with coordinates of simultaneity respectively \
the same positions from FoR B entered, we get the equations of lines of \
simultaneity respectively the same position in point of view of FoR A. As we \
can see, the higher is the speed v the more skewed is the coordinate system \
of FoR B inside FoR A. Also interval of axes ticks on FoR B is dilating as \
the speed is increasing.\
\>", "DetailNotes",
 CellChangeTimes->{{3.5779838141383824`*^9, 3.577983979371904*^9}, {
   3.57798411604657*^9, 3.577984341348098*^9}, 3.5779843743063936`*^9, {
   3.577984583102271*^9, 3.5779847453964987`*^9}, {3.577984779374896*^9, 
   3.577985120190974*^9}},
 CellID->478582935],

Cell["\<\
Reference: Wikipedia, Lorentz transformation, \
http://en.wikipedia.org/wiki/Lorentz_transformation (optional description \
here) (as of May 19, 2013, 20:50 GMT). \
\>", "DetailNotes",
 CellChangeTimes->{{3.577985488952847*^9, 3.5779854960055523`*^9}},
 CellID->74600009]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ControlSuggestionsSection"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Resize Images"]}],
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"ResizeImages"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Rotate and Zoom in 3D"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" on Mac) and drag up and down to zoom.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"RotateAndZoomIn3D"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[True], Cell[" Drag Locators"]}],
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 CellChangeTimes->{3.5779835789938703`*^9},
 FontFamily->"Verdana",
 CellTags->"DragLocators"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Create and Delete Locators"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"CreateAndDeleteLocators"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Slider Zoom"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" to make ever finer adjustments.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"SliderZoom"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Gamepad Controls"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->"GamepadControls"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Automatic Animation"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"AutomaticAnimation"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[" Bookmark Animation"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->"BookmarkAnimation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SearchTermsSection"],

Cell["Lorentz", "SearchTerms",
 CellChangeTimes->{{3.5779852236483192`*^9, 3.5779852279107456`*^9}, {
  3.5779853117221255`*^9, 3.577985312114165*^9}},
 CellID->373692960],

Cell["transformation", "SearchTerms",
 CellChangeTimes->{{3.5779852352044744`*^9, 3.5779852384067945`*^9}},
 CellID->275621299],

Cell["special theory of relativity", "SearchTerms",
 CellChangeTimes->{{3.5779852055885134`*^9, 3.5779852147894335`*^9}},
 CellID->243135832],

Cell["time dilation", "SearchTerms",
 CellChangeTimes->{{3.5779852452434783`*^9, 3.5779852491028643`*^9}},
 CellID->57525601],

Cell["length contraction", "SearchTerms",
 CellChangeTimes->{{3.5779852530642605`*^9, 3.577985258791833*^9}},
 CellID->375677424],

Cell["simultaneity", "SearchTerms",
 CellChangeTimes->{{3.5779852623841925`*^9, 3.577985267823736*^9}},
 CellID->285401818]
}, Open  ]],

Cell["", "RelatedLinksSection"],

Cell[CellGroupData[{

Cell["", "AuthorSection"],

Cell["Contributed by: Jakub Serych", "Author",
 CellChangeTimes->{{3.5779853011690702`*^9, 3.5779853034653*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{700, Automatic},
WindowMargins->{{421, Automatic}, {Automatic, 101}},
FrontEndVersion->"9.0 for Microsoft Windows (32-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "WindowsEastEurope"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ResizeImages"->{
  Cell[136500, 3365, 312, 8, 22, "ControlSuggestions",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[136815, 3375, 678, 16, 22, "ControlSuggestions",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[137496, 3393, 383, 12, 22, "ControlSuggestions",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[137882, 3407, 637, 15, 22, "ControlSuggestions",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[138522, 3424, 844, 21, 22, "ControlSuggestions",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[139369, 3447, 369, 9, 22, "ControlSuggestions",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[139741, 3458, 1464, 31, 22, "ControlSuggestions",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[141208, 3491, 908, 21, 22, "ControlSuggestions",
   CellTags->"BookmarkAnimation"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ResizeImages", 143645, 3567},
 {"RotateAndZoomIn3D", 143755, 3570},
 {"DragLocators", 143866, 3573},
 {"CreateAndDeleteLocators", 143983, 3576},
 {"SliderZoom", 144098, 3579},
 {"GamepadControls", 144205, 3582},
 {"AutomaticAnimation", 144319, 3585},
 {"BookmarkAnimation", 144437, 3588}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 111, 1, 74, "DemoTitle"],
Cell[CellGroupData[{
Cell[715, 27, 33, 0, 287, "InitializationSection"],
Cell[751, 29, 2630, 85, 269, "Input",
 InitializationCell->True,
 CellID->43547898]
}, Open  ]],
Cell[CellGroupData[{
Cell[3418, 119, 29, 0, 236, "ManipulateSection"],
Cell[CellGroupData[{
Cell[3472, 123, 40313, 997, 2808, "Input"],
Cell[43788, 1122, 19117, 467, 941, "Output",
 CellID->237248868]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62954, 1595, 36, 0, 169, "ManipulateCaptionSection"],
Cell[62993, 1597, 708, 11, 97, "ManipulateCaption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63738, 1613, 28, 0, 173, "ThumbnailSection"],
Cell[63769, 1615, 17150, 414, 909, "Output",
 CellID->2339421]
}, Open  ]],
Cell[CellGroupData[{
Cell[80956, 2034, 28, 0, 143, "SnapshotsSection"],
Cell[80987, 2036, 52869, 1251, 2768, "Input",
 CellID->167508588]
}, Open  ]],
Cell[CellGroupData[{
Cell[133893, 3292, 26, 0, 336, "DetailsSection"],
Cell[133922, 3294, 405, 8, 37, "DetailNotes",
 CellID->610034143],
Cell[134330, 3304, 1101, 32, 90, "DetailNotes",
 CellID->3037942],
Cell[135434, 3338, 705, 12, 82, "DetailNotes",
 CellID->478582935],
Cell[136142, 3352, 281, 6, 52, "DetailNotes",
 CellID->74600009]
}, Open  ]],
Cell[CellGroupData[{
Cell[136460, 3363, 37, 0, 126, "ControlSuggestionsSection"],
Cell[136500, 3365, 312, 8, 22, "ControlSuggestions",
 CellTags->"ResizeImages"],
Cell[136815, 3375, 678, 16, 22, "ControlSuggestions",
 CellTags->"RotateAndZoomIn3D"],
Cell[137496, 3393, 383, 12, 22, "ControlSuggestions",
 CellTags->"DragLocators"],
Cell[137882, 3407, 637, 15, 22, "ControlSuggestions",
 CellTags->"CreateAndDeleteLocators"],
Cell[138522, 3424, 844, 21, 22, "ControlSuggestions",
 CellTags->"SliderZoom"],
Cell[139369, 3447, 369, 9, 22, "ControlSuggestions",
 CellTags->"GamepadControls"],
Cell[139741, 3458, 1464, 31, 22, "ControlSuggestions",
 CellTags->"AutomaticAnimation"],
Cell[141208, 3491, 908, 21, 22, "ControlSuggestions",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142153, 3517, 30, 0, 155, "SearchTermsSection"],
Cell[142186, 3519, 171, 3, 22, "SearchTerms",
 CellID->373692960],
Cell[142360, 3524, 127, 2, 22, "SearchTerms",
 CellID->275621299],
Cell[142490, 3528, 141, 2, 22, "SearchTerms",
 CellID->243135832],
Cell[142634, 3532, 125, 2, 22, "SearchTerms",
 CellID->57525601],
Cell[142762, 3536, 129, 2, 22, "SearchTerms",
 CellID->375677424],
Cell[142894, 3540, 123, 2, 22, "SearchTerms",
 CellID->285401818]
}, Open  ]],
Cell[143032, 3545, 31, 0, 141, "RelatedLinksSection"],
Cell[CellGroupData[{
Cell[143088, 3549, 25, 0, 129, "AuthorSection"],
Cell[143116, 3551, 112, 1, 22, "Author"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
